==> webkit2gtk_2.16.3.orig.tar.xz: webkitgtk-2.16.3/Source/WebCore/English.lproj/mediaControlsLocalizedStrings.js <==
var UIStringTable = {
    '##WIRELESS_PLAYBACK_DEVICE_TYPE##': 'AirPlay',
    '##WIRELESS_PLAYBACK_DEVICE_NAME##': 'This video is playing on “##DEVICE_NAME##”.',

    '##TVOUT_DEVICE_TYPE##': 'TV Connected',
    '##TVOUT_DEVICE_NAME##': 'This video is playing on the TV.',

    'Aborted': 'Aborted',
    'Audio': 'Audio',
    'Audio Playback': 'Audio Playback',
    'Captions': 'Captions',
    'Choose Wireless Display': 'Choose Wireless Display',
    'Display Full Screen': 'Display Full Screen',
    'Display Picture in Picture': 'Display Picture in Picture',
    'Duration': 'Duration',
    'Elapsed': 'Elapsed',
    'Error': 'Error',
    'Exit Full Screen': 'Exit Full Screen',
    'Fast Forward': 'Fast Forward',
    'Hour' : 'Hour',
    'Hours': 'Hours',
    'Live Broadcast': 'Live Broadcast',
    'Loading': 'Loading',
    'Maximum Volume': 'Maximum Volume',
    'Minimum Volume': 'Minimum Volume',
    'Minute': 'Minute',
    'Minutes': 'Minutes',
    'Mute': 'Mute',
    'Pause': 'Pause',
    'Play': 'Play',
    'Remaining': 'Remaining',
    'Rewind': 'Rewind',
    'Rewind ##sec## Seconds': 'Rewind ##sec## Seconds',
    'Second': 'Second',
    'Seconds': 'Seconds',
    'Show Controls': 'Show Controls',
    'Stalled': 'Stalled',
    'Start Playback': 'Start Playback',
    'Subtitles': 'Subtitles',
    'Suspended': 'Suspended',
    'This video is playing in Picture in Picture': 'This video is playing in Picture in Picture',
    'Unmute': 'Unmute',
    'Video Playback': 'Video Playback',
    'Video Playback Placeholder': 'Video Playback Placeholder',
    'Volume': 'Volume',
    'Waiting': 'Waiting'
};

==> webkit2gtk_2.20.1.orig.tar.xz: webkitgtk-2.20.1/Source/WebCore/English.lproj/mediaControlsLocalizedStrings.js <==
var UIStringTable = {
    '##WIRELESS_PLAYBACK_DEVICE_TYPE##': 'AirPlay',
    '##WIRELESS_PLAYBACK_DEVICE_NAME##': 'This video is playing on “##DEVICE_NAME##”.',

    '##TVOUT_DEVICE_TYPE##': 'TV Connected',
    '##TVOUT_DEVICE_NAME##': 'This video is playing on the TV.',

    'Aborted': 'Aborted',
    'Audio': 'Audio',
    'Audio Playback': 'Audio Playback',
    'Captions': 'Captions',
    'Choose Wireless Display': 'Choose Wireless Display',
    'Display Full Screen': 'Display Full Screen',
    'Display Picture in Picture': 'Display Picture in Picture',
    'Duration': 'Duration',
    'Elapsed': 'Elapsed',
    'Error': 'Error',
    'Exit Full Screen': 'Exit Full Screen',
    'Fast Forward': 'Fast Forward',
    'Hour' : 'Hour',
    'Hours': 'Hours',
    'Live Broadcast': 'Live Broadcast',
    'Loading': 'Loading',
    'Maximum Volume': 'Maximum Volume',
    'Minimum Volume': 'Minimum Volume',
    'Minute': 'Minute',
    'Minutes': 'Minutes',
    'Mute': 'Mute',
    'Pause': 'Pause',
    'Play': 'Play',
    'Remaining': 'Remaining',
    'Rewind': 'Rewind',
    'Rewind ##sec## Seconds': 'Rewind ##sec## Seconds',
    'Second': 'Second',
    'Seconds': 'Seconds',
    'Show Controls': 'Show Controls',
    'Stalled': 'Stalled',
    'Start Playback': 'Start Playback',
    'Subtitles': 'Subtitles',
    'Suspended': 'Suspended',
    'This video is playing in picture in picture.': 'This video is playing in picture in picture.',
    'Unmute': 'Unmute',
    'Video Playback': 'Video Playback',
    'Video Playback Placeholder': 'Video Playback Placeholder',
    'Volume': 'Volume',
    'Waiting': 'Waiting'
};
